<?php

namespace EventPortal\Http\Middleware;

use Closure;
use Illuminate\Http\Request;
use Spatie\Permission\Exceptions\UnauthorizedException;

class CurrentTeam
{
    /**
     * Handle an incoming request.
     *
     * @phpcsSuppress SlevomatCodingStandard.TypeHints.ParameterTypeHint.UselessAnnotation
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure  $next
     * @return mixed
     */
    public function handle(Request $request, Closure $next)
    {
        if (auth()->guest()) {
            throw UnauthorizedException::notLoggedIn();
        }

        if (auth()->user()->admin->hasRole('super-admin')) {
            return $next($request);
        }

        if ($request->has('event_id') || $request->route('event')) {
            $event = $request->route('event_id') ?? $request->route('event');

            if ($event->doesNoBelongToSameTeamAs(auth()->user()->admin)) {
                abort(401, 'You don\'t have permission to view this page.');
            }
        }

        return $next($request);
    }
}
